==> TACZ-Refabricated-1.20.1-0.1.2-forge1.1.6-hotfix-sources.jar: com/tacz/guns/item/AmmoItem.java <==
package com.tacz.guns.item;

import cn.sh1rocu.tacz.api.extension.IItem;
import com.tacz.guns.api.TimelessAPI;
import com.tacz.guns.api.item.IAmmo;
import com.tacz.guns.api.item.builder.AmmoItemBuilder;
import com.tacz.guns.api.item.nbt.AmmoItemDataAccessor;
import com.tacz.guns.client.renderer.item.AmmoItemRenderer;
import com.tacz.guns.client.resource.ClientAssetsManager;
import com.tacz.guns.client.resource.index.ClientAmmoIndex;
import com.tacz.guns.client.resource.pojo.PackInfo;
import com.tacz.guns.resource.index.CommonAmmoIndex;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_124;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1836;
import net.minecraft.class_1937;
import net.minecraft.class_2371;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_5250;
import net.minecraft.class_756;
import org.jetbrains.annotations.Nullable;

import javax.annotation.Nonnull;
import java.util.List;
import java.util.Optional;

public class AmmoItem extends class_1792 implements AmmoItemDataAccessor, IItem {
    public AmmoItem() {
        super(new class_1793().method_7889(1));
    }

    @Override
    public int tacz$getMaxStackSize(class_1799 stack) {
        if (stack.method_7909() instanceof IAmmo iAmmo) {
            return TimelessAPI.getCommonAmmoIndex(iAmmo.getAmmoId(stack))
                    .map(CommonAmmoIndex::getStackSize).orElse(1);
        }
        return 1;
    }

    @Override
    @Nonnull
    @Environment(EnvType.CLIENT)
    public class_2561 method_7864(@Nonnull class_1799 stack) {
        class_2960 ammoId = this.getAmmoId(stack);
        Optional<ClientAmmoIndex> ammoIndex = TimelessAPI.getClientAmmoIndex(ammoId);
        if (ammoIndex.isPresent()) {
            return class_2561.method_43471(ammoIndex.get().getName());
        }
        return super.method_7864(stack);
    }

    public static class_2371<class_1799> fillItemCategory() {
        class_2371<class_1799> stacks = class_2371.method_10211();
        TimelessAPI.getAllCommonAmmoIndex().forEach(entry -> {
            class_1799 itemStack = AmmoItemBuilder.create().setId(entry.getKey()).build();
            stacks.add(itemStack);
        });
        return stacks;
    }

    @Override
    @Environment(EnvType.CLIENT)
    public class_756 getCustomRenderer() {
        return AmmoItemRenderer.INSTANCE.get();
    }

    @Override
    @Environment(EnvType.CLIENT)
    public void method_7851(class_1799 stack, @Nullable class_1937 level, List<class_2561> components, class_1836 isAdvanced) {
        class_2960 ammoId = this.getAmmoId(stack);
        TimelessAPI.getClientAmmoIndex(ammoId).ifPresent(index -> {
            String tooltipKey = index.getTooltipKey();
            if (tooltipKey != null) {
                components.add(class_2561.method_43471(tooltipKey).method_27692(class_124.field_1080));
            }
        });

        PackInfo packInfoObject = ClientAssetsManager.INSTANCE.getPackInfo(ammoId);
        if (packInfoObject != null) {
            class_5250 component = class_2561.method_43471(packInfoObject.getName()).method_27692(class_124.field_1078).method_27692(class_124.field_1056);
            components.add(component);
        }
    }
}

==> TACZ-Refabricated-1.21.1-0.0.3.1-forge1.1.6-hotfix-sources.jar: com/tacz/guns/item/AmmoItem.java <==
package com.tacz.guns.item;

import cn.sh1rocu.tacz.api.extension.IItem;
import com.tacz.guns.api.TimelessAPI;
import com.tacz.guns.api.item.builder.AmmoItemBuilder;
import com.tacz.guns.api.item.nbt.AmmoItemDataAccessor;
import com.tacz.guns.client.renderer.item.AmmoItemRenderer;
import com.tacz.guns.client.resource.ClientAssetsManager;
import com.tacz.guns.client.resource.index.ClientAmmoIndex;
import com.tacz.guns.client.resource.pojo.PackInfo;
import com.tacz.guns.resource.index.CommonAmmoIndex;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_124;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1836;
import net.minecraft.class_2371;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_5250;
import net.minecraft.class_756;
import net.minecraft.class_9334;
import org.jetbrains.annotations.NotNull;

import javax.annotation.Nonnull;
import java.util.List;
import java.util.Optional;

public class AmmoItem extends class_1792 implements AmmoItemDataAccessor, IItem {
    public AmmoItem() {
        super(new class_1793().method_7889(1));
    }

    @Override
    public void method_7860(@NotNull class_1799 stack) {
        TimelessAPI.getCommonAmmoIndex(this.getAmmoId(stack)).map(CommonAmmoIndex::getStackSize).ifPresent(maxStackSize ->
                stack.method_57379(class_9334.field_50071, maxStackSize)
        );
    }

    @Override
    @Nonnull
    @Environment(EnvType.CLIENT)
    public class_2561 method_7864(@Nonnull class_1799 stack) {
        class_2960 ammoId = this.getAmmoId(stack);
        Optional<ClientAmmoIndex> ammoIndex = TimelessAPI.getClientAmmoIndex(ammoId);
        if (ammoIndex.isPresent()) {
            return class_2561.method_43471(ammoIndex.get().getName());
        }
        return super.method_7864(stack);
    }

    public static class_2371<class_1799> fillItemCategory() {
        class_2371<class_1799> stacks = class_2371.method_10211();
        TimelessAPI.getAllCommonAmmoIndex().forEach(entry -> {
            class_1799 itemStack = AmmoItemBuilder.create().setId(entry.getKey()).build();
            stacks.add(itemStack);
        });
        return stacks;
    }

    @Override
    @Environment(EnvType.CLIENT)
    public class_756 getCustomRenderer() {
        class_310 minecraft = class_310.method_1551();
        return new AmmoItemRenderer(minecraft.method_31975(), minecraft.method_31974());
    }

    @Override
    @Environment(EnvType.CLIENT)
    public void method_7851(class_1799 stack, class_9635 context, List<class_2561> components, class_1836 isAdvanced) {
        class_2960 ammoId = this.getAmmoId(stack);
        TimelessAPI.getClientAmmoIndex(ammoId).ifPresent(index -> {
            String tooltipKey = index.getTooltipKey();
            if (tooltipKey != null) {
                components.add(class_2561.method_43471(tooltipKey).method_27692(class_124.field_1080));
            }
        });

        PackInfo packInfoObject = ClientAssetsManager.INSTANCE.getPackInfo(ammoId);
        if (packInfoObject != null) {
            class_5250 component = class_2561.method_43471(packInfoObject.getName()).method_27692(class_124.field_1078).method_27692(class_124.field_1056);
            components.add(component);
        }
    }
}
